@@ -1,4 +1,4 @@
-/* bug-buddy bug submitting program
+/*  bug-buddy bug submitting program
  *
  * Copyright (C) 2000 Jacob Berkman
  *
@@ -126,6 +126,45 @@ mail_lock_text (void)
 	}
 }
 
+static gboolean
+check_old_version (void)
+{
+
+	GDateDay   day;
+	GDateMonth month;
+	GDateYear  year;
+	GDate *gnome_date, *current_date;
+	static gboolean checked = FALSE;
+
+	if (checked == TRUE) {
+		return FALSE;
+	} else {
+		checked = TRUE;
+	}
+
+	if (druid_data.gnome_date) {
+		year = atoi (strtok (druid_data.gnome_date, "-"));
+		month = atoi (strtok (NULL, "-"));
+		day = atoi (strtok (NULL, "-"));
+	} else {
+		return FALSE;
+	}
+
+	gnome_date = g_date_new_dmy (day, month, year);
+	current_date = g_date_new ();
+	g_date_set_time (current_date, time (NULL));
+	g_date_add_months (gnome_date, 6);
+
+	if (g_date_compare (gnome_date, current_date) < 0) {
+		return TRUE;
+	}
+
+	return FALSE;
+}
+
+
+
+
 void
 druid_set_sensitive (gboolean prev, gboolean next, gboolean cancel)
 {
@@ -216,6 +255,17 @@ void invalid_description (void) {
        	gtk_widget_destroy (w);
 }
 
+void
+on_email_file_gnome_entry_browse_clicked (GtkWidget *button, gpointer data)
+{
+	/* Set the filechooser in the entry to save mode. Access
+	 * directly ->fsw is ugly, but no way using gnome_file_entry
+	 * API */
+	GnomeFileEntry *file_entry = GNOME_FILE_ENTRY (GET_WIDGET ("email-file-gnome-entry"));
+	gtk_file_chooser_set_action (GTK_FILE_CHOOSER (file_entry->fsw), GTK_FILE_CHOOSER_ACTION_SAVE);
+}
+	
+
 void
 druid_set_state (BuddyState state)
 {
@@ -256,8 +306,22 @@ druid_set_state (BuddyState state)
 		if (druid_data.bug_type==BUG_DEBUG) {
 			GtkWidget *nb;
 			nb = GET_WIDGET ("gdb-notebook");
+
 			gtk_notebook_set_current_page (GTK_NOTEBOOK (nb), 1);
 			gtk_widget_hide (GET_WIDGET ("debugging-options-button"));
+		} else if (check_old_version() == TRUE) {
+			GtkLabel *label;
+			const gchar *str;
+			gchar *newstr;
+
+			label = GTK_LABEL (GET_WIDGET ("gdb-label"));
+			str = gtk_label_get_text (label);
+			newstr = g_strdup_printf (_("%s\n\nNotice that the software you are running (%s) is older than six months.\nYou may want to consider upgrading to a newer version of %s system"), 
+					     str, 
+					     druid_data.gnome_platform_version,
+					     druid_data.gnome_distributor);
+			gtk_label_set_text (label, newstr);
+			g_free (newstr);
 		}
 		break;
 	case STATE_PRODUCT:
@@ -924,16 +988,22 @@ on_druid_next_clicked (GtkWidget *w, gpointer data)
 			break;
 		
 		application = g_hash_table_lookup(druid_data.program_to_application, druid_data.current_appname);
-		if (!application || !application->bugzilla || !application->product)
+		if (!application || !application->bugzilla || !application->product) {
+			products_list_load ();
 			break;
+		}
 
 		bts = g_hash_table_lookup (druid_data.bugzillas, application->bugzilla);
-		if (!bts)
+		if (!bts) {
+			products_list_load ();
 	       		break;
+		}
 		
 		product = g_hash_table_lookup (bts->products, application->product);
-		if (!product)
+		if (!product) {
+			products_list_load ();
 			break;
+		}
 		
 		druid_data.product = product;
 		bugzilla_product_add_components_to_clist (druid_data.product);
@@ -1108,23 +1178,7 @@ on_druid_next_clicked (GtkWidget *w, gpointer data)
 
 void
 on_druid_cancel_clicked (GtkWidget *w, gpointer data)
-{
-	GtkWidget *d;
-
-	d = gtk_message_dialog_new (GTK_WINDOW (GET_WIDGET ("druid-window")),
-				    0,
-				    GTK_MESSAGE_QUESTION,
-				    GTK_BUTTONS_YES_NO,
-				    _("Are you sure you want to cancel\n"
-				      "this bug report?"));
-	gtk_dialog_set_default_response (GTK_DIALOG (d),
-					 GTK_RESPONSE_YES);
-	if (GTK_RESPONSE_YES != gtk_dialog_run (GTK_DIALOG (d))) {
-		gtk_widget_destroy (d);
-		return;
-	}
-	gtk_widget_destroy (d);
-
+{       
 	stop_gdb ();
 	gtk_main_quit ();
 }
